import matplotlib.pyplot as plt
import pystan
import seaborn as sb
import numpy as np
import scipy.stats as ss

Data = [(74, 48), (67, 55), (70, 76), (68, 81), (81, 80),
        (70, 75), (65, 44), (63, 45), (64, 52), (78, 82),
        (71, 73), (96, 96), (72, 70), (53, 43), (66, 62),
        (59, 44), (78, 77), (57, 54), (72, 62), (71, 65)
        ]

StanData = {'N': len(Data), 'Data': Data}

sm = pystan.StanModel(file = 'AnalBiNormal.stan')
fit = sm.sampling(data = StanData, n_jobs = 1)
print(fit)

rho_mean = fit['rho'].mean()
rho_025P, rho_975P = np.percentile(fit['rho'], [2.5, 97.5])
sb.kdeplot(fit['rho'])
plt.title('Posterior distribution of rho' +
          '\nMean = {0:.3f}   95%CI = [{1:.3f}, {2:.3f}]'.format(
              rho_mean, rho_025P, rho_975P), fontsize = 16)
plt.xlabel('rho', fontsize = 14)
plt.yticks([])
plt.show()

muA_mean = fit['muA'].mean()
muA_025P, muA_975P = np.percentile(fit['muA'], [2.5, 97.5])
muB_mean = fit['muB'].mean()
muB_025P, muB_975P = np.percentile(fit['muB'], [2.5, 97.5])

plt.figure(figsize = (10, 4))

plt.subplot(121)
plt.title('Posterior distribution of muA' +
          '\nmean = {0:.1f}   95%CI = [{1:.1f}, {2:.1f}]'.format(
              muA_mean, muA_025P, muA_975P))
sb.kdeplot(fit['muA'])
plt.yticks([])
plt.xlabel('muA')

plt.subplot(122)
plt.title('Posterior distribution of muB' +
          '\nmean = {0:.1f}   95%CI = [{1:.1f}, {2:.1f}]'.format(
              muB_mean, muB_025P, muB_975P))
sb.kdeplot(fit['muB'])
plt.yticks([])
plt.xlabel('muB')

plt.show()

sgmA_mean = fit['sgmA'].mean()
sgmA_025P, sgmA_975P = np.percentile(fit['sgmA'], [2.5, 97.5])
sgmB_mean = fit['sgmB'].mean()
sgmB_025P, sgmB_975P = np.percentile(fit['sgmB'], [2.5, 97.5])

plt.figure(figsize = (10, 4))

plt.subplot(121)
plt.title('Posterior distribution of sgmA' +
          '\nmean = {0:.1f}   95%CI = [{1:.1f}, {2:.1f}]'.format(
              sgmA_mean, sgmA_025P, sgmA_975P))
sb.kdeplot(fit['sgmA'])
plt.yticks([])
plt.xlabel('sgmA')

plt.subplot(122)
plt.title('Posterior distribution of sgmB' +
          '\nmean = {0:.1f}   95%CI = [{1:.1f}, {2:.1f}]'.format(
              sgmB_mean, sgmB_025P, sgmB_975P))
sb.kdeplot(fit['sgmB'])
plt.yticks([])
plt.xlabel('sgmB')

plt.show()

tndncy = []
for ma, mb, sgm in zip(fit['muA'], fit['muB'], fit['sgm']):
    v1 = ss.multivariate_normal.rvs([ma, mb], sgm)
    v2 = ss.multivariate_normal.rvs([ma, mb], sgm)
    #print(v1, v2)
    tndncy.append(1 if (v1[0] - v2[0])*(v1[1] - v2[1]) > 0.0 else 0)
    #print(tndncy[-1])
p_tndncy = np.array(tndncy).mean()
print('\nPosterior predictive Prob(da*db>0) = {0:.3f}\n'.format(p_tndncy))
