import matplotlib.pyplot as plt
import numpy as np
import pystan
import seaborn as sb
import scipy.stats as ss

dataA = [126, 122, 120, 132, 129,
         124, 124, 125, 124, 124,
         121, 121, 130, 125, 129
         ] 
dataB = [126, 139, 137, 130, 139,
         132, 128, 137, 134, 137,
         131, 133, 136, 131, 130,
         134, 141, 135, 136, 133
         ]

StanData = {'NA': len(dataA), 'DataA': dataA,
            'NB': len(dataB), 'DataB': dataB}

sm = pystan.StanModel(file = 'AnalInd.stan')
fit = sm.sampling(data = StanData, n_jobs = 1)
print(fit)

mean_mu_d = fit['mu_d'].mean()
mu_d025P, mu_d975P = np.percentile(fit['mu_d'], [2.5, 97.5])
sb.kdeplot(fit['mu_d'])
plt.title('Posterior distribution of mu_d' +
          '\nmean = {0:.2f}   95%CI = [{1:.2f}, {2:.2f}]'.format(
              mean_mu_d, mu_d025P, mu_d975P), fontsize = 16)
plt.yticks([])
plt.xlabel('mu_d', fontsize = 14)
plt.show()

plt.title('Posterior distributions', fontsize = 16)
sb.kdeplot(fit['muA'], label = 'muA')
sb.kdeplot(fit['muB'], label = 'muB')
plt.yticks([])
plt.legend(fontsize = 12)
plt.show()

sb.kdeplot(fit['sgm'])
plt.title('Posterior distribution of sgm', fontsize = 16)
plt.yticks([])
plt.show()
#
#       Posterior prediction of difference
#
diff = []
for ma, mb, s in zip(fit['muA'], fit['muB'], fit['sgm']):
    va = ss.norm.rvs(ma, s)
    vb = ss.norm.rvs(mb, s)
    diff.append(va - vb)
diff = np.array(diff)
p_pos_diff = (diff > 0.0).sum() / len(diff)
sb.kdeplot(diff)
plt.title('Posterior prediction of Differences A - B' +
          '\nProb(A-B > 0) = {0:.3f}'.format(p_pos_diff), fontsize = 16)
plt.xlabel('A - B', fontsize = 14)
plt.yticks([])
plt.show()
