import matplotlib.pyplot as plt
import numpy as np
import pystan
import seaborn as sb
import scipy.stats as ss

Data = [(133, 123), (133, 127), (136, 129), (136, 132),
        (134, 127), (136, 127), (131, 118), (139, 134),
        (135, 129), (140, 130), (132, 124), (130, 122),
        (138, 127), (138, 124), (130, 118), (137, 119),
        (131, 123), (135, 128), (136, 120), (134, 129)
        ]

StanData = {'N': len(Data), 'dt': Data}

sm = pystan.StanModel(file = 'AnalPair.stan')
fit = sm.sampling(data = StanData, n_jobs = 1)
print(fit)

mu025P, mu975P = np.percentile(fit['mu'], [2.5, 97.5])
sb.kdeplot(fit['mu'])
plt.yticks([])
plt.xlabel('mu', fontsize = 12)
plt.title('Posterior distribution of mu' +
          '\nMean = {0:.1f}, 95%CI = [{1:.1f}, {2:.1f}]'.format(
          fit['mu'].mean(), mu025P, mu975P) , fontsize = 14)
plt.show()

sgm025P, sgm975P = np.percentile(fit['sgm'], [2.5, 97.5])
sb.kdeplot(fit['sgm'])
plt.yticks([])
plt.xlabel('sigma', fontsize = 12)
plt.title('Posterior distribution of sigma' +
          '\nMean = {0:.1f}, 95%CI = [{1:.1f}, {2:.1f}]'.format(
          fit['sgm'].mean(), sgm025P, sgm975P) , fontsize = 14)
plt.show()
#
#   Posterior prediction of difference
#
d_post = []
for m, s in zip(fit['mu'], fit['sgm']):
    d_post.append(ss.norm.rvs(m, s))
d_post = np.array(d_post)
p_pos = (d_post > 0.0).sum() / len(d_post)
    
sb.kdeplot(d_post)
plt.xlabel('diff.', fontsize = 14)
plt.title('Posterior prediction of difference' +
          '\nProb(diff. > 0) = {0:.3f}'.format(p_pos), fontsize = 14)
plt.show()
